@@ -27,14 +27,10 @@
 
 #pragma once
 
-#include <clutter-gtk/clutter-gtk.h>
-
-#ifndef glib_autoptr_clear_GtkClutterEmbed
-G_DEFINE_AUTOPTR_CLEANUP_FUNC(GtkClutterEmbed, g_object_unref)
-#endif
+#include <gtk/gtk.h>
 
 #define BACON_TYPE_VIDEO_WIDGET		     (bacon_video_widget_get_type ())
-G_DECLARE_FINAL_TYPE(BaconVideoWidget, bacon_video_widget, BACON, VIDEO_WIDGET, GtkClutterEmbed)
+G_DECLARE_FINAL_TYPE(BaconVideoWidget, bacon_video_widget, BACON, VIDEO_WIDGET, GtkOverlay)
 #define BVW_ERROR bacon_video_widget_error_quark ()
 
 /**
@@ -90,7 +86,9 @@ GQuark bacon_video_widget_error_quark		 (void) G_GNUC_CONST;
 GType bacon_video_widget_get_type                (void);
 GOptionGroup* bacon_video_widget_get_option_group (void);
 
-GtkWidget *bacon_video_widget_new		 (GError **error);
+GtkWidget *bacon_video_widget_new		 (void);
+gboolean bacon_video_widget_check_init		 (BaconVideoWidget  *bvw,
+						  GError           **error);
 
 /* Actions */
 void bacon_video_widget_open			 (BaconVideoWidget *bvw,
@@ -129,12 +127,6 @@ double bacon_video_widget_get_volume             (BaconVideoWidget *bvw);
 /* Properties */
 void bacon_video_widget_set_text_subtitle	(BaconVideoWidget * bvw,
 						 const gchar * subtitle_uri);
-void bacon_video_widget_set_logo		 (BaconVideoWidget *bvw,
-						  const char *name);
-void  bacon_video_widget_set_logo_mode		 (BaconVideoWidget *bvw,
-						  gboolean logo_mode);
-gboolean bacon_video_widget_get_logo_mode	 (BaconVideoWidget *bvw);
-
 void bacon_video_widget_set_subtitle_font	 (BaconVideoWidget *bvw,
 						  const char *font);
 void bacon_video_widget_set_subtitle_encoding	 (BaconVideoWidget *bvw,
@@ -150,8 +142,8 @@ gboolean bacon_video_widget_set_rate		 (BaconVideoWidget *bvw,
 						  gfloat new_rate);
 gfloat bacon_video_widget_get_rate		 (BaconVideoWidget *bvw);
 
-void bacon_video_widget_set_fullscreen           (BaconVideoWidget *bvw,
-                                                  gboolean          fullscreen);
+void bacon_video_widget_set_show_cursor          (BaconVideoWidget *bvw,
+						  gboolean          show_cursor);
 
 /* Metadata */
 /**
@@ -163,7 +155,6 @@ void bacon_video_widget_set_fullscreen           (BaconVideoWidget *bvw,
  * @BVW_INFO_ALBUM: the album in which the work was released
  * @BVW_INFO_DURATION: the stream's duration, in seconds
  * @BVW_INFO_TRACK_NUMBER: the track number of the work on the album
- * @BVW_INFO_COVER: a #GdkPixbuf of the cover artwork
  * @BVW_INFO_CONTAINER: the type of stream container
  * @BVW_INFO_HAS_VIDEO: whether the stream has video
  * @BVW_INFO_DIMENSION_X: the video's width, in pixels
@@ -188,7 +179,6 @@ typedef enum {
 	BVW_INFO_ALBUM,
 	BVW_INFO_DURATION,
 	BVW_INFO_TRACK_NUMBER,
-	BVW_INFO_COVER,
 	BVW_INFO_CONTAINER,
 	/* Video */
 	BVW_INFO_HAS_VIDEO,
@@ -349,19 +339,27 @@ void bacon_video_widget_dvd_event                (BaconVideoWidget *bvw,
 
 /**
  * BvwLangInfo:
+ * @title: the title of the track, or %NULL if unset.
  * @language: the ISO-639 language code for the track, or "und" if unknown.
- * Can never be %NULL.
+ *   Can never be %NULL.
  * @codec: the codec for the track, or %NULL if unknown or unset.
+ * @index: an opaque track identifier.
  *
- * #BvwLangInfo holds the language code and codec for each subtitle
- * or audio track for a media, which would allow the front-ends to
- * present appropriate information to the user.
+ * #BvwLangInfo holds the title, language code and codec for each
+ * subtitle or audio track for a media, which would allow the
+ * front-ends to present appropriate information to the user.
  */
 typedef struct {
+	char *title;
 	char *language;
 	char *codec;
+	guint id;
 } BvwLangInfo;
 
+void         bacon_video_widget_lang_info_free           (BvwLangInfo *info);
+
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(BvwLangInfo, bacon_video_widget_lang_info_free)
+
 /**
  * BvwTrackType:
  * @BVW_TRACK_TYPE_AUDIO: an audio track
@@ -376,8 +374,6 @@ typedef enum {
 	BVW_TRACK_TYPE_VIDEO
 } BvwTrackType;
 
-void bacon_video_widget_lang_info_free           (BvwLangInfo *info);
-
 GList *bacon_video_widget_get_languages          (BaconVideoWidget *bvw);
 int bacon_video_widget_get_language              (BaconVideoWidget *bvw);
 void bacon_video_widget_set_language             (BaconVideoWidget *bvw,
@@ -389,6 +385,7 @@ int bacon_video_widget_get_subtitle              (BaconVideoWidget *bvw);
 void bacon_video_widget_set_subtitle             (BaconVideoWidget *bvw,
 		                                  int subtitle);
 void bacon_video_widget_set_next_subtitle        (BaconVideoWidget *bvw);
+void bacon_video_toggle_subtitles                (BaconVideoWidget *bvw);
 
 gboolean bacon_video_widget_has_next_track	 (BaconVideoWidget *bvw);
 gboolean bacon_video_widget_has_previous_track	 (BaconVideoWidget *bvw);
@@ -423,13 +420,3 @@ BvwAudioOutputType bacon_video_widget_get_audio_output_type
 						 (BaconVideoWidget *bvw);
 void bacon_video_widget_set_audio_output_type    (BaconVideoWidget *bvw,
 						  BvwAudioOutputType type);
-
-/* OSD */
-void bacon_video_widget_show_popup                (BaconVideoWidget *bvw);
-void bacon_video_widget_mark_popup_busy           (BaconVideoWidget *bvw,
-						   const char       *reason);
-void bacon_video_widget_unmark_popup_busy         (BaconVideoWidget *bvw,
-						   const char       *reason);
-
-GObject * bacon_video_widget_get_controls_object  (BaconVideoWidget *bvw);
-GObject * bacon_video_widget_get_header_controls_object (BaconVideoWidget *bvw);
