@@ -194,6 +194,9 @@ thumbnail_media_async_thread (GTask    *task,
 	const char *uri;
 	GDateTime *mtime;
 	gint64 unix_date;
+#if defined(GNOME_DESKTOP_PLATFORM_VERSION) && GNOME_DESKTOP_PLATFORM_VERSION >= 43
+	GError *error = NULL;
+#endif
 
 	if (g_task_return_error_if_cancelled (task)) {
 		g_object_unref (task);
@@ -220,6 +223,24 @@ thumbnail_media_async_thread (GTask    *task,
 		return;
 	}
 
+#if defined(GNOME_DESKTOP_PLATFORM_VERSION) && GNOME_DESKTOP_PLATFORM_VERSION >= 43
+	tmp_pixbuf = gnome_desktop_thumbnail_factory_generate_thumbnail (factory, uri, "video/x-totem-stream", NULL, &error);
+
+	if (!tmp_pixbuf) {
+		g_task_return_new_error (task, G_IO_ERROR, G_IO_ERROR_FAILED, "Thumbnailing failed: %s", error->message);
+		g_object_unref (task);
+		g_error_free (error);
+		return;
+	}
+
+	gnome_desktop_thumbnail_factory_save_thumbnail (factory, tmp_pixbuf, uri, unix_date, NULL, &error);
+	if (error) {
+		g_task_return_new_error (task, G_IO_ERROR, G_IO_ERROR_FAILED, "Thumbnailing failed: %s", error->message);
+		g_object_unref (task);
+		g_error_free (error);
+		return;
+	}
+#else
 	tmp_pixbuf = gnome_desktop_thumbnail_factory_generate_thumbnail (factory, uri, "video/x-totem-stream");
 
 	if (!tmp_pixbuf) {
@@ -229,6 +250,7 @@ thumbnail_media_async_thread (GTask    *task,
 	}
 
 	gnome_desktop_thumbnail_factory_save_thumbnail (factory, tmp_pixbuf, uri, unix_date);
+#endif
 
 	/* Save the thumbnail URL for the bookmarks source */
 	save_bookmark_thumbnail (media, uri);
@@ -519,7 +541,7 @@ void
 totem_grilo_setup_icons (void)
 {
 	icons[ICON_BOX] = load_named_icon ("folder-symbolic", VIDEO_ICON_SIZE, FILL_DEFAULT);
-	icons[ICON_CHANNEL] = load_named_icon ("tv-symbolic", VIDEO_ICON_SIZE, FILL_DEFAULT);
+	icons[ICON_CHANNEL] = load_named_icon ("totem-tv-symbolic", VIDEO_ICON_SIZE, FILL_DEFAULT);
 	icons[ICON_VIDEO] = load_named_icon ("folder-videos-symbolic", VIDEO_ICON_SIZE, FILL_DEFAULT);
 	icons[ICON_VIDEO_THUMBNAILING] = load_named_icon ("content-loading-symbolic", VIDEO_ICON_SIZE, FILL_TRANSPARENT);
 	icons[ICON_OPTICAL] = load_named_icon ("media-optical-dvd-symbolic", VIDEO_ICON_SIZE, FILL_DEFAULT);
