@@ -42,24 +42,21 @@
 
 #define TOTEM_TYPE_SCREENSHOT_PLUGIN		(totem_screenshot_plugin_get_type ())
 #define TOTEM_SCREENSHOT_PLUGIN(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), TOTEM_TYPE_SCREENSHOT_PLUGIN, TotemScreenshotPlugin))
-#define TOTEM_SCREENSHOT_PLUGIN_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST((k), TOTEM_TYPE_SCREENSHOT_PLUGIN, TotemScreenshotPluginClass))
-#define TOTEM_IS_SCREENSHOT_PLUGIN(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), TOTEM_TYPE_SCREENSHOT_PLUGIN))
-#define TOTEM_IS_SCREENSHOT_PLUGIN_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), TOTEM_TYPE_SCREENSHOT_PLUGIN))
-#define TOTEM_SCREENSHOT_PLUGIN_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), TOTEM_TYPE_SCREENSHOT_PLUGIN, TotemScreenshotPluginClass))
 
 typedef struct {
+	PeasExtensionBase parent;
+
 	Totem *totem;
 	BaconVideoWidget *bvw;
 
 	gulong got_metadata_signal;
-	gulong notify_logo_mode_signal;
 
 	GSettings *settings;
 	gboolean save_to_disk;
 
 	GSimpleAction *screenshot_action;
 	GSimpleAction *gallery_action;
-} TotemScreenshotPluginPrivate;
+} TotemScreenshotPlugin;
 
 TOTEM_PLUGIN_REGISTER(TOTEM_TYPE_SCREENSHOT_PLUGIN,
 		      TotemScreenshotPlugin,
@@ -200,52 +197,55 @@ flash_area (GtkWidget *widget)
 			   NULL);
 }
 
+static char *
+escape_video_name (const char *orig)
+{
+	g_auto(GStrv) elems = NULL;
+
+	/* '/' can't be in a filename */
+	elems = g_strsplit (orig, "/", -1);
+	return g_strjoinv ("–", elems);
+}
+
 static void
 take_screenshot_action_cb (GSimpleAction         *action,
 			   GVariant              *parameter,
-			   TotemScreenshotPlugin *self)
+			   TotemScreenshotPlugin *pi)
 {
-	TotemScreenshotPluginPrivate *priv = self->priv;
 	GdkPixbuf *pixbuf;
 	GError *err = NULL;
 	ScreenshotSaveJob *job;
-	char *video_name;
+	g_autofree char *video_name = NULL;
+	g_autofree char *escaped_video_name = NULL;
 
-	if (bacon_video_widget_get_logo_mode (priv->bvw) != FALSE)
-		return;
-
-	if (bacon_video_widget_can_get_frames (priv->bvw, &err) == FALSE) {
-		if (err == NULL)
-			return;
-
-		totem_object_show_error (priv->totem, _("Totem could not get a screenshot of the video."), err->message);
+	if (bacon_video_widget_can_get_frames (pi->bvw, &err) == FALSE) {
+		totem_object_show_error (pi->totem, _("Videos could not get a screenshot of the video."), err->message ?: _("No reason."));
 		g_error_free (err);
 		return;
 	}
 
-	flash_area (GTK_WIDGET (priv->bvw));
+	flash_area (GTK_WIDGET (pi->bvw));
 
-	pixbuf = bacon_video_widget_get_current_frame (priv->bvw);
+	pixbuf = bacon_video_widget_get_current_frame (pi->bvw);
 	if (pixbuf == NULL) {
-		totem_object_show_error (priv->totem, _("Totem could not get a screenshot of the video."), _("This is not supposed to happen; please file a bug report."));
+		totem_object_show_error (pi->totem, _("Videos could not get a screenshot of the video."), _("This is not supposed to happen; please file a bug report."));
 		return;
 	}
 
-	video_name = totem_object_get_short_title (self->priv->totem);
+	video_name = totem_object_get_short_title (pi->totem);
+	escaped_video_name = escape_video_name (video_name);
 
 	job = g_slice_new (ScreenshotSaveJob);
-	job->plugin = self;
+	job->plugin = pi;
 	job->pixbuf = pixbuf;
 
-	screenshot_build_filename_async (NULL, video_name, screenshot_name_ready_cb, job);
-
-	g_free (video_name);
+	screenshot_build_filename_async (NULL, escaped_video_name, screenshot_name_ready_cb, job);
 }
 
 static void
 take_gallery_response_cb (GtkDialog *dialog,
 			  int response_id,
-			  TotemScreenshotPlugin *self)
+			  TotemScreenshotPlugin *pi)
 {
 	if (response_id != GTK_RESPONSE_OK)
 		gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -254,88 +254,70 @@ take_gallery_response_cb (GtkDialog *dialog,
 static void
 take_gallery_action_cb (GAction               *action,
 			GVariant              *parameter,
-			TotemScreenshotPlugin *self)
+			TotemScreenshotPlugin *pi)
 {
-	Totem *totem = self->priv->totem;
 	GtkDialog *dialog;
 
-	if (bacon_video_widget_get_logo_mode (self->priv->bvw) != FALSE)
-		return;
-
-	dialog = GTK_DIALOG (totem_gallery_new (totem));
+	dialog = GTK_DIALOG (totem_gallery_new (pi->totem));
 
 	g_signal_connect (dialog, "response",
-			  G_CALLBACK (take_gallery_response_cb), self);
+			  G_CALLBACK (take_gallery_response_cb), pi);
 	gtk_widget_show (GTK_WIDGET (dialog));
 }
 
 static void
-update_state (TotemScreenshotPlugin *self)
+update_state (TotemScreenshotPlugin *pi)
 {
-	TotemScreenshotPluginPrivate *priv = self->priv;
 	gboolean sensitive;
 
-	sensitive = bacon_video_widget_can_get_frames (priv->bvw, NULL) &&
-		    (bacon_video_widget_get_logo_mode (priv->bvw) == FALSE) &&
-		    priv->save_to_disk;
+	sensitive = bacon_video_widget_can_get_frames (pi->bvw, NULL) &&
+		    pi->save_to_disk;
 
-	g_simple_action_set_enabled (G_SIMPLE_ACTION (priv->screenshot_action), sensitive);
-	g_simple_action_set_enabled (G_SIMPLE_ACTION (priv->gallery_action), sensitive);
+	g_simple_action_set_enabled (G_SIMPLE_ACTION (pi->screenshot_action), sensitive);
+	g_simple_action_set_enabled (G_SIMPLE_ACTION (pi->gallery_action), sensitive);
 }
 
 static void
-got_metadata_cb (BaconVideoWidget *bvw, TotemScreenshotPlugin *self)
+got_metadata_cb (BaconVideoWidget *bvw, TotemScreenshotPlugin *pi)
 {
-	update_state (self);
+	update_state (pi);
 }
 
 static void
-notify_logo_mode_cb (GObject *object, GParamSpec *pspec, TotemScreenshotPlugin *self)
+disable_save_to_disk_changed_cb (GSettings *settings, const gchar *key, TotemScreenshotPlugin *pi)
 {
-	update_state (self);
-}
-
-static void
-disable_save_to_disk_changed_cb (GSettings *settings, const gchar *key, TotemScreenshotPlugin *self)
-{
-	self->priv->save_to_disk = !g_settings_get_boolean (settings, "disable-save-to-disk");
+	pi->save_to_disk = !g_settings_get_boolean (settings, "disable-save-to-disk");
 }
 
 static void
 impl_activate (PeasActivatable *plugin)
 {
-	TotemScreenshotPlugin *self = TOTEM_SCREENSHOT_PLUGIN (plugin);
-	TotemScreenshotPluginPrivate *priv = self->priv;
+	TotemScreenshotPlugin *pi = TOTEM_SCREENSHOT_PLUGIN (plugin);
 	GMenu *menu;
 	GMenuItem *item;
 	const char * const accels[]= { "<Primary><Alt>s", NULL };
 
-	priv->totem = g_object_get_data (G_OBJECT (plugin), "object");
-	priv->bvw = BACON_VIDEO_WIDGET (totem_object_get_video_widget (priv->totem));
-	priv->got_metadata_signal = g_signal_connect (G_OBJECT (priv->bvw),
+	pi->totem = g_object_get_data (G_OBJECT (plugin), "object");
+	pi->bvw = BACON_VIDEO_WIDGET (totem_object_get_video_widget (pi->totem));
+	pi->got_metadata_signal = g_signal_connect (G_OBJECT (pi->bvw),
 						      "got-metadata",
 						      G_CALLBACK (got_metadata_cb),
-						      self);
-	priv->notify_logo_mode_signal = g_signal_connect (G_OBJECT (priv->bvw),
-							  "notify::logo-mode",
-							  G_CALLBACK (notify_logo_mode_cb),
-							  self);
-
-	priv->screenshot_action = g_simple_action_new ("take-screenshot", NULL);
-	g_signal_connect (G_OBJECT (priv->screenshot_action), "activate",
+						      pi);
+	pi->screenshot_action = g_simple_action_new ("take-screenshot", NULL);
+	g_signal_connect (G_OBJECT (pi->screenshot_action), "activate",
 			  G_CALLBACK (take_screenshot_action_cb), plugin);
-	g_action_map_add_action (G_ACTION_MAP (priv->totem), G_ACTION (priv->screenshot_action));
-	gtk_application_set_accels_for_action (GTK_APPLICATION (priv->totem),
+	g_action_map_add_action (G_ACTION_MAP (pi->totem), G_ACTION (pi->screenshot_action));
+	gtk_application_set_accels_for_action (GTK_APPLICATION (pi->totem),
 					       "app.take-screenshot",
 					       accels);
 
-	priv->gallery_action = g_simple_action_new ("take-gallery", NULL);
-	g_signal_connect (G_OBJECT (priv->gallery_action), "activate",
+	pi->gallery_action = g_simple_action_new ("take-gallery", NULL);
+	g_signal_connect (G_OBJECT (pi->gallery_action), "activate",
 			  G_CALLBACK (take_gallery_action_cb), plugin);
-	g_action_map_add_action (G_ACTION_MAP (priv->totem), G_ACTION (priv->gallery_action));
+	g_action_map_add_action (G_ACTION_MAP (pi->totem), G_ACTION (pi->gallery_action));
 
 	/* Install the menu */
-	menu = totem_object_get_menu_section (priv->totem, "screenshot-placeholder");
+	menu = totem_object_get_menu_section (pi->totem, "screenshot-placeholder");
 	item = g_menu_item_new (_("Take _Screenshot"), "app.take-screenshot");
 	g_menu_item_set_attribute (item, "accel", "s", "<Primary><Alt>s");
 	g_menu_item_set_attribute_value (item, "hidden-when",
@@ -349,35 +331,34 @@ impl_activate (PeasActivatable *plugin)
 	g_object_unref (item);
 
 	/* Set up a GSettings watch for lockdown keys */
-	priv->settings = g_settings_new ("org.gnome.desktop.lockdown");
-	g_signal_connect (priv->settings, "changed::disable-save-to-disk", (GCallback) disable_save_to_disk_changed_cb, self);
-	disable_save_to_disk_changed_cb (priv->settings, "disable-save-to-disk", self);
+	pi->settings = g_settings_new ("org.gnome.desktop.lockdown");
+	g_signal_connect (pi->settings, "changed::disable-save-to-disk", (GCallback) disable_save_to_disk_changed_cb, pi);
+	disable_save_to_disk_changed_cb (pi->settings, "disable-save-to-disk", pi);
 
 	/* Update the menu entries' states */
-	update_state (self);
+	update_state (pi);
 }
 
 static void
 impl_deactivate (PeasActivatable *plugin)
 {
-	TotemScreenshotPluginPrivate *priv = TOTEM_SCREENSHOT_PLUGIN (plugin)->priv;
+	TotemScreenshotPlugin *pi = TOTEM_SCREENSHOT_PLUGIN (plugin);
 	const char * const accels[] = { NULL };
 
 	/* Disconnect signal handlers */
-	g_signal_handler_disconnect (G_OBJECT (priv->bvw), priv->got_metadata_signal);
-	g_signal_handler_disconnect (G_OBJECT (priv->bvw), priv->notify_logo_mode_signal);
+	g_signal_handler_disconnect (G_OBJECT (pi->bvw), pi->got_metadata_signal);
 
-	gtk_application_set_accels_for_action (GTK_APPLICATION (priv->totem),
+	gtk_application_set_accels_for_action (GTK_APPLICATION (pi->totem),
 					       "app.take-screenshot",
 					       accels);
 
 	/* Disconnect from GSettings */
-	g_object_unref (priv->settings);
+	g_object_unref (pi->settings);
 
 	/* Remove the menu */
-	totem_object_empty_menu_section (priv->totem, "screenshot-placeholder");
+	totem_object_empty_menu_section (pi->totem, "screenshot-placeholder");
 
-	g_object_unref (priv->bvw);
+	g_object_unref (pi->bvw);
 }
 
 static char *make_filename_for_dir (const char *directory, const char *format, const char *movie_title) G_GNUC_FORMAT (2);
@@ -417,13 +398,13 @@ totem_screenshot_plugin_setup_file_chooser (const char *filename_format, const c
 	path = g_settings_get_string (settings, "screenshot-save-uri");
 	g_object_unref (settings);
 
-	/* Default to the Pictures directory */
+	/* Default to the Screenshots directory */
 	if (*path == '\0') {
 		g_free (path);
-		path = totem_pictures_dir ();
-		/* No pictures dir, then it's the home dir */
+		path = get_default_screenshot_dir ();
+		/* No Screenshots dir, then it's the home dir */
 		if (path == NULL)
-			path = g_strdup (g_get_home_dir ());
+			path = get_fallback_screenshot_dir ();
 	}
 
 	filename = make_filename_for_dir (path, filename_format, movie_title);
