@@ -25,8 +25,7 @@
  * See license_change file for details.
  */
 
-#ifndef TOTEM_SCREENSHOT_PLUGIN_H
-#define TOTEM_SCREENSHOT_PLUGIN_H
+#pragma once
 
 #include <glib.h>
 
@@ -34,11 +33,5 @@
 #include <libpeas/peas-extension-base.h>
 #include <libpeas/peas-object-module.h>
 
-G_BEGIN_DECLS
-
 gchar *totem_screenshot_plugin_setup_file_chooser (const char *filename_format, const char *movie_name) G_GNUC_WARN_UNUSED_RESULT G_GNUC_FORMAT (1);
 void totem_screenshot_plugin_update_file_chooser (const char *filename);
-
-G_END_DECLS
-
-#endif /* !TOTEM_SCREENSHOT_PLUGIN_H */
