@@ -37,12 +37,24 @@
 
 #include "totem-profile.h"
 
+static void
+main_menu_cb (GSimpleAction *action,
+	      GVariant      *parameter,
+	      gpointer       user_data)
+{
+	TotemObject *totem = user_data;
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (totem->main_menu_button),
+				      !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (totem->main_menu_button)));
+}
+
 static void
 open_action_cb (GSimpleAction *action,
 		GVariant      *parameter,
 		gpointer       user_data)
 {
-	totem_object_open (TOTEM_OBJECT (user_data));
+	TotemObject *totem = user_data;
+	totem_object_set_fullscreen (totem, FALSE);
+	totem_object_open (totem);
 }
 
 static void
@@ -50,7 +62,9 @@ open_location_action_cb (GSimpleAction *action,
 			 GVariant      *parameter,
 			 gpointer       user_data)
 {
-	totem_object_open_location (TOTEM_OBJECT (user_data));
+	TotemObject *totem = user_data;
+	totem_object_set_fullscreen (totem, FALSE);
+	totem_object_open_location (totem);
 }
 
 static void
@@ -298,6 +312,7 @@ remote_command_cb (GSimpleAction *action,
 
 static GActionEntry app_entries[] = {
 	/* Main app menu */
+	{ "main-menu", main_menu_cb, NULL, NULL, NULL },
 	{ "open", open_action_cb, NULL, NULL, NULL },
 	{ "open-location", open_location_action_cb, NULL, NULL, NULL },
 	{ "fullscreen", toggle_action_cb, NULL, "false", fullscreen_change_state },
@@ -341,7 +356,7 @@ totem_app_actions_setup (Totem *totem)
 void
 totem_app_menu_setup (Totem *totem)
 {
-	char *accels[] = { NULL, NULL };
+	char *accels[] = { NULL, NULL, NULL };
 	const char * const shortcuts_accels[] = {
 		"<Ctrl>H",
 		"<Ctrl>question",
@@ -350,6 +365,8 @@ totem_app_menu_setup (Totem *totem)
 	};
 
 	/* FIXME: https://gitlab.gnome.org/GNOME/glib/issues/700 */
+	accels[0] = "F10";
+	gtk_application_set_accels_for_action (GTK_APPLICATION (totem), "app.main-menu", (const char * const *) accels);
 	accels[0] = "<Primary>G";
 	gtk_application_set_accels_for_action (GTK_APPLICATION (totem), "app.next-angle", (const char * const *) accels);
 	accels[0] = "<Primary>M";
@@ -357,6 +374,14 @@ totem_app_menu_setup (Totem *totem)
 	accels[0] = "<Primary>E";
 	gtk_application_set_accels_for_action (GTK_APPLICATION (totem), "app.eject", (const char * const *) accels);
 	gtk_application_set_accels_for_action (GTK_APPLICATION (totem), "app.shortcuts", shortcuts_accels);
+	accels[0] = "F1";
+	gtk_application_set_accels_for_action (GTK_APPLICATION (totem), "app.help", (const char * const *) accels);
+	accels[0] = "<Primary>l";
+	accels[1] = "OpenURL";
+	gtk_application_set_accels_for_action (GTK_APPLICATION (totem), "app.open-location", (const char * const *) accels);
+	accels[0] = "<Primary>o";
+	accels[1] = "Open";
+	gtk_application_set_accels_for_action (GTK_APPLICATION (totem), "app.open", (const char * const *) accels);
 	gtk_window_set_application (GTK_WINDOW (totem->win), GTK_APPLICATION (totem));
 }
 
@@ -419,6 +444,43 @@ get_language_name_no_und (const char   *lang,
 	return NULL;
 }
 
+void
+free_menu_item (MenuItem *item)
+{
+	if (!item)
+		return;
+	g_free (item->label);
+	g_free (item);
+}
+
+static MenuItem *
+create_menu_item (char *str,
+		  int   id)
+{
+	MenuItem *menu_item;
+	menu_item = g_new0 (MenuItem, 1);
+	menu_item->label = str;
+	menu_item->id = id;
+	return menu_item;
+}
+
+static MenuItem *
+create_special_menu_item (BvwLangInfo *info)
+{
+	const char *label;
+
+	if (g_strcmp0 (info->codec, "auto") == 0) {
+		/* Translators: an entry in the "Languages" menu, used to choose the audio language of a DVD */
+		label = C_("Language", "Auto");
+	} else if (g_strcmp0 (info->codec, "none") == 0) {
+		/* Translators: an entry in the "Subtitles" menu, used to choose the subtitle language of a DVD */
+		label = _("None");
+	} else
+		return NULL;
+
+	return create_menu_item (g_strdup (_(label)), info->id);
+}
+
 GList *
 bvw_lang_info_to_menu_labels (GList        *langs,
 			      BvwTrackType  track_type)
@@ -435,6 +497,9 @@ bvw_lang_info_to_menu_labels (GList        *langs,
 		int num;
 		char *id;
 
+		if (!info->language)
+			continue;
+
 		num = hash_table_num_instances (lang_table, info->language);
 		num++;
 		g_hash_table_insert (lang_table,
@@ -453,9 +518,16 @@ bvw_lang_info_to_menu_labels (GList        *langs,
 	printed_table = g_hash_table_new (g_str_hash, g_str_equal);
 	for (l = langs; l != NULL; l = l->next) {
 		BvwLangInfo *info = l->data;
+		MenuItem *menu_item;
 		int num;
 		char *str;
 
+		menu_item = create_special_menu_item (info);
+		if (menu_item) {
+			ret = g_list_prepend (ret, menu_item);
+			continue;
+		}
+
 		num = hash_table_num_instances (lang_table, info->language);
 		g_assert (num >= 1);
 		if (num > 1) {
@@ -483,7 +555,7 @@ bvw_lang_info_to_menu_labels (GList        *langs,
 			str = g_strdup (get_language_name_no_und (info->language, track_type));
 		}
 
-		ret = g_list_prepend (ret, str);
+		ret = g_list_prepend (ret, create_menu_item (str, info->id));
 	}
 
 	g_hash_table_destroy (printed_table);
@@ -510,13 +582,12 @@ static void
 add_lang_action (GMenu *menu,
 		 const char *action,
 		 const char *label,
-		 int lang_id)
+		 int         id)
 {
-	char *escaped_label;
+	g_autofree char *escaped_label = NULL;
 
 	escaped_label = escape_label_for_menu (label);
-	add_lang_item (menu, escaped_label, action, lang_id);
-	g_free (escaped_label);
+	add_lang_item (menu, escaped_label, action, id);
 }
 
 static void
@@ -526,55 +597,15 @@ create_lang_actions (GMenu        *menu,
 		     BvwTrackType  track_type)
 {
 	GList *ui_list, *l;
-	guint i;
-
-	if (track_type == BVW_TRACK_TYPE_SUBTITLE) {
-		/* Translators: an entry in the "Subtitles" menu, used to choose the subtitle language of a DVD */
-		add_lang_action (menu, action, _("None"), -2);
-	}
-
-	/* Translators: an entry in the "Languages" menu, used to choose the audio language of a DVD */
-	add_lang_action (menu, action, C_("Language", "Auto"), -1);
 
 	ui_list = bvw_lang_info_to_menu_labels (list, track_type);
 
-	for (l = ui_list, i = 0; l != NULL; l = l->next, i++)
-		add_lang_action (menu, action, l->data, i);
-
-	g_list_free_full (ui_list, (GDestroyNotify) g_free);
-}
-
-static gboolean
-totem_sublang_equal_lists (GList *orig, GList *new)
-{
-	GList *o, *n;
-	gboolean retval;
-
-	if ((orig == NULL && new != NULL) || (orig != NULL && new == NULL))
-		return FALSE;
-	if (orig == NULL && new == NULL)
-		return TRUE;
-
-	if (g_list_length (orig) != g_list_length (new))
-		return FALSE;
-
-	retval = TRUE;
-	o = orig;
-	n = new;
-	while (o != NULL && n != NULL && retval != FALSE) {
-		BvwLangInfo *info_o, *info_n;
-
-		info_o = o->data;
-		info_n = n->data;
-		if (g_strcmp0 (info_o->language, info_n->language) != 0)
-			retval = FALSE;
-		if (g_strcmp0 (info_o->codec, info_n->codec) != 0)
-			retval = FALSE;
-                o = g_list_next (o);
-                n = g_list_next (n);
+	for (l = ui_list; l != NULL; l = l->next) {
+		MenuItem *item = l->data;
+		add_lang_action (menu, action, item->label, item->id);
 	}
 
-	return retval;
+	g_list_free_full (ui_list, (GDestroyNotify) free_menu_item);
 }
 
 static void
@@ -597,9 +628,6 @@ totem_languages_update (Totem *totem, GList *list)
 	current = bacon_video_widget_get_language (totem->bvw);
 	g_action_change_state (action, g_variant_new_int32 (current));
 	totem->updating_menu = FALSE;
-
-	g_list_free_full (totem->languages_list, (GDestroyNotify) bacon_video_widget_lang_info_free);
-	totem->languages_list = list;
 }
 
 static void
@@ -622,34 +650,22 @@ totem_subtitles_update (Totem *totem, GList *list)
 	current = bacon_video_widget_get_subtitle (totem->bvw);
 	g_action_change_state (action, g_variant_new_int32 (current));
 	totem->updating_menu = FALSE;
-
-	g_list_free_full (totem->subtitles_list, (GDestroyNotify) bacon_video_widget_lang_info_free);
-	totem->subtitles_list = list;
 }
 
 void
-totem_sublang_update (Totem *totem)
+totem_subtitles_menu_update (Totem *totem)
+{
+	GList *list;
+
+	list = bacon_video_widget_get_subtitles (totem->bvw);
+	totem_subtitles_update (totem, list);
+}
+
+void
+totem_languages_menu_update (Totem *totem)
 {
 	GList *list;
 
 	list = bacon_video_widget_get_languages (totem->bvw);
-	if (totem_sublang_equal_lists (totem->languages_list, list) == TRUE) {
-		g_list_free_full (list, (GDestroyNotify) bacon_video_widget_lang_info_free);
-	} else {
-		totem_languages_update (totem, list);
-	}
-
-	list = bacon_video_widget_get_subtitles (totem->bvw);
-	if (totem_sublang_equal_lists (totem->subtitles_list, list) == TRUE) {
-		g_list_free_full (list, (GDestroyNotify) bacon_video_widget_lang_info_free);
-	} else {
-		totem_subtitles_update (totem, list);
-	}
-}
-
-void
-totem_sublang_exit (Totem *totem)
-{
-	g_list_free_full (totem->subtitles_list, (GDestroyNotify) bacon_video_widget_lang_info_free);
-	g_list_free_full (totem->languages_list, (GDestroyNotify) bacon_video_widget_lang_info_free);
+	totem_languages_update (totem, list);
 }
