@@ -25,8 +25,7 @@
  *
  */
 
-#ifndef __TOTEM_PRIVATE_H__
-#define __TOTEM_PRIVATE_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include <gio/gio.h>
@@ -37,24 +36,6 @@
 #include "totem-open-location.h"
 #include "totem-plugins-engine.h"
 
-#define totem_signal_block_by_data(obj, data) (g_signal_handlers_block_matched (obj, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, data))
-#define totem_signal_unblock_by_data(obj, data) (g_signal_handlers_unblock_matched (obj, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, data))
-
-#define totem_set_sensitivity(xml, name, state)					\
-	{									\
-		GtkWidget *widget;						\
-		widget = GTK_WIDGET (gtk_builder_get_object (xml, name));	\
-		gtk_widget_set_sensitive (widget, state);			\
-	}
-#define totem_controls_set_sensitivity(name, state) gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (totem->xml, name)), state)
-
-#define totem_object_set_sensitivity2(name, state)					\
-	{										\
-		GAction *__action;							\
-		__action = g_action_map_lookup_action (G_ACTION_MAP (totem), name);	\
-		g_simple_action_set_enabled (G_SIMPLE_ACTION (__action), state);	\
-	}
-
 typedef enum {
 	TOTEM_CONTROLS_UNDEFINED,
 	TOTEM_CONTROLS_VISIBLE,
@@ -145,10 +126,13 @@ struct _TotemObject {
 
 	char *player_title;
 
+	/* Playlist */
+	TotemPlaylist *playlist;
+	GSignalGroup *playlist_signals;
+
 	/* other */
 	char *mrl;
 	char *next_subtitle;
-	TotemPlaylist *playlist;
 	GSettings *settings;
 	TotemStates state;
 	TotemOpenLocation *open_location;
@@ -156,8 +140,6 @@ struct _TotemObject {
 	gboolean has_played_emitted;
 };
 
-GtkWidget *totem_volume_create (void);
-
 #define SEEK_FORWARD_OFFSET 60
 #define SEEK_BACKWARD_OFFSET -15
 
@@ -167,42 +149,18 @@ GtkWidget *totem_volume_create (void);
 #define VOLUME_DOWN_SHORT_OFFSET (-0.02)
 #define VOLUME_UP_SHORT_OFFSET (0.02)
 
-#define ZOOM_IN_OFFSET 0.01
-#define ZOOM_OUT_OFFSET -0.01
-
 void	totem_object_open			(Totem *totem);
 void	totem_object_open_location		(Totem *totem);
 void	totem_object_eject			(Totem *totem);
-void	totem_object_set_zoom			(Totem *totem, gboolean zoom);
 void	totem_object_show_help			(Totem *totem);
 void	totem_object_show_keyboard_shortcuts	(Totem *totem);
-void	totem_object_show_properties		(Totem *totem);
 void    totem_object_set_mrl			(TotemObject *totem,
 						 const char *mrl,
 						 const char *subtitle);
-gboolean totem_object_open_files		(Totem *totem, char **list);
-G_GNUC_NORETURN void totem_object_show_error_and_exit (const char *title, const char *reason, Totem *totem);
 
-void	show_controls				(Totem *totem, gboolean was_fullscreen);
-
-void	totem_setup_window			(Totem *totem);
-void	totem_callback_connect			(Totem *totem);
-void	playlist_widget_setup			(Totem *totem);
-void	grilo_widget_setup			(Totem *totem);
-void	video_widget_create			(Totem *totem);
-void    totem_object_plugins_init		(TotemObject *totem);
-void    totem_object_plugins_shutdown		(TotemObject *totem);
 void	totem_object_set_fullscreen		(TotemObject *totem, gboolean state);
-void	totem_object_set_volume_relative	(TotemObject *totem, double off_pct);
-void	totem_object_volume_toggle_mute		(TotemObject *totem);
 void	totem_object_set_main_page		(TotemObject *totem,
 						 const char  *page_id);
 const char * totem_object_get_main_page		(Totem *totem);
 void	totem_object_add_items_to_playlist	(TotemObject *totem,
 						 GList       *items);
-
-/* Signal emission */
-void	totem_file_has_played			(TotemObject *totem,
-						 const char *mrl);
-
-#endif /* __TOTEM_PRIVATE_H__ */
